.. _gallery_overview:

*******
Gallery
*******

Galleries are a collection of images. They are used to display a
list of thumbnails and a larger view of the selected image. See
:ref:`responsive images <response_images_overview>` for more
information about thumbnails.
